@@ -18,7 +18,6 @@
 import os
 from io import StringIO
 from itertools import cycle
-from urllib.request import urlopen
 from PIL import Image
 from PIL import ImageDraw
 from PIL import ImageEnhance
@@ -370,7 +369,7 @@ def fill_background_color(image, color):
     else:
         mode = 'RGB'
     back = Image.new(mode, image.size, color)
-    if (image.mode == 'P' and mode == 'RGBA'):
+    if image.mode == 'P' and mode == 'RGBA':
         image = image.convert('RGBA')
     if has_alpha(image):
         paste(back, image, mask=image)
@@ -620,31 +619,6 @@ def has_transparency(image):
         has_alpha(image)
 
 
-if Image.VERSION == '1.1.7':
-
-    def split(image):
-        """Work around for bug in Pil 1.1.7
-
-        :param image: input image
-        :type image: PIL image object
-        :returns: the different color bands of the image (eg R, G, B)
-        :rtype: tuple
-        """
-        image.load()
-        return image.split()
-else:
-
-    def split(image):
-        """Work around for bug in Pil 1.1.7
-
-        :param image: input image
-        :type image: PIL image object
-        :returns: the different color bands of the image (eg R, G, B)
-        :rtype: tuple
-        """
-        return image.split()
-
-
 def get_alpha(image):
     """Gets the image alpha band. Can handles P mode images with transpareny.
     Returns a band with all values set to 255 if no alpha band exists.
@@ -655,7 +629,7 @@ def get_alpha(image):
     :rtype: single band image object
     """
     if has_alpha(image):
-        return split(image)[-1]
+        return image.split()[-1]
     if image.mode == 'P' and 'transparency' in image.info:
         return image.convert('RGBA').split()[-1]
     # No alpha layer, create one.
@@ -781,7 +755,7 @@ def put_palette(image_to, image_from, palette=None):
     :param palette: image palette
     :type palette: sequence of (r, g, b) tuples or None
     """
-    if palette == None:
+    if palette is None:
         palette = get_palette(image_from)
     image_to.putpalette(flatten(palette))
     if 'transparency' in image_from.info:
@@ -879,7 +853,7 @@ def paste(destination, source, box=(0, 0), mask=None, force=False):
             source_without_alpha = remove_alpha(source)
             # paste on top of the opaque destination pixels
             destination.paste(source_without_alpha, box, source)
-            if invert_alpha != None:
+            if invert_alpha is not None:
                 # the alpha channel is ok now, so save it
                 destination_alpha = get_alpha(destination)
                 # paste on top of the transparant destination pixels
@@ -946,7 +920,7 @@ def convert(image, mode, *args, **keyw):
         # A workaround for a PIL bug.
         # Converting from P to LA directly doesn't work.
         return image.convert('RGBA').convert('LA', *args, **keyw)
-    if has_transparency(image) and (not mode in ['RGBA', 'LA']):
+    if has_transparency(image) and (mode not in ['RGBA', 'LA']):
         if image.mode == 'P':
             image = image.convert('RGBA')
             del image.info['transparency']
@@ -988,7 +962,7 @@ def convert_save_mode_by_format(image, format):
     #TODO: Extend this helper function to support other formats as well
     if image.mode == 'P':
         # Make sure P is handled correctly
-        if not format in ['GIF', 'PNG', 'TIFF', 'IM', 'PCX']:
+        if format not in ['GIF', 'PNG', 'TIFF', 'IM', 'PCX']:
             image = remove_alpha(image)
     if format == 'JPEG':
         if image.mode in ['RGBA', 'P']:
@@ -1037,7 +1011,7 @@ def convert_save_mode_by_format(image, format):
         if image.mode in ['P', 'RGBA', 'YCbCr']:
             return image.convert('RGB')
     elif format == 'XBM':
-        if not image.mode in ['1']:
+        if image.mode not in ['1']:
             return image.convert('1')
     elif format == 'TIFF':
         if image.mode in ['YCbCr']:
@@ -1201,16 +1175,16 @@ def checkboard(size, delta=8, fg=(128, 128, 128), bg=(204, 204, 204)):
     :returns: checkboard image
     :rtype: pil.Image
     """
-    if not (size in CHECKBOARD):
+    if size not in CHECKBOARD:
         dim = max(size)
         n = int(dim / delta) + 1  # FIXME: now acts like square->nx, ny
 
         def sq_start(i):
-            "Return the x/y start coord of the square at column/row i."
+            """Return the x/y start coord of the square at column/row i."""
             return i * delta
 
         def square(i, j):
-            "Return the square corners"
+            """Return the square corners"""
             return map(sq_start, [i, j, i + 1, j + 1])
 
         image = Image.new("RGB", size, bg)
