@@ -241,6 +241,7 @@ var WindowManager = class WindowManager {
         this._resizePending = new Set();
         this._destroying = new Set();
         this._movingWindow = null;
+        this._seenWindows = new Set();
 
         this.wm_settings = new Gio.Settings({schema_id: 'org.cinnamon.muffin'});
 
@@ -324,6 +325,52 @@ var WindowManager = class WindowManager {
         });
 
         this._windowMenuManager = new WindowMenu.WindowMenuManager();
+
+        // Minimized windows won't be reliable clone sources until they're
+        // shown once. If they start minimized, monitor them until they've
+        // been shown for the first time. (See windowUtils.js)
+        const handleSeen = (metaWindow) => {
+            if (this.windowSeen(metaWindow) || metaWindow === null || !Main.isInteresting(metaWindow)) {
+                return;
+            }
+
+            if (metaWindow.get_workspace().index() !== global.workspace_manager.get_active_workspace_index()) {
+                return;
+            }
+
+            if (!metaWindow.minimized) {
+                this._seenWindows.add(metaWindow);
+                return;
+            }
+
+            // If not, add it when it gets unminimized.
+            let minimize_id = metaWindow.connect("notify::minimized", () => {
+                if (!metaWindow.minimized) {
+                    this._seenWindows.add(metaWindow);
+                }
+            });
+
+            metaWindow.connect("unmanaging", () => {
+                metaWindow.disconnect(minimize_id);
+                this._seenWindows.delete(metaWindow);
+            });
+        }
+
+        global.display.connect("window-created", (display, metaWindow) => {
+            handleSeen(metaWindow);
+        });
+
+        global.workspace_manager.connect("workspace-switched", (from, to, direction) => {
+            const allWindowActors = Meta.get_window_actors(global.display);
+            allWindowActors.forEach((actor) => handleSeen(actor.meta_window));
+        });
+
+        const allWindowActors = Meta.get_window_actors(global.display);
+        allWindowActors.forEach((actor) => handleSeen(actor.meta_window));
+    }
+
+    windowSeen(metaWindow) {
+        return this._seenWindows.has(metaWindow);
     }
 
     _filterKeybinding(shellwm, binding) {
@@ -373,7 +420,6 @@ var WindowManager = class WindowManager {
             case Meta.WindowType.MENU:
             case Meta.WindowType.DROPDOWN_MENU:
             case Meta.WindowType.POPUP_MENU:
-                return this.desktop_effects_menus;
             default:
                 return false;
         }
@@ -817,20 +863,14 @@ var WindowManager = class WindowManager {
             return;
         }
 
-        // menu effects are always fade-in/out
-        let overridden_types = [Meta.WindowType.MENU,
-                                Meta.WindowType.DROPDOWN_MENU,
-                                Meta.WindowType.POPUP_MENU    ];
-
         this._mapping.add(actor);
 
-        let adjusted_type = overridden_types.includes(actor._windowType) ? "traditional" : this.desktop_effects_map_type;
-
-        switch (adjusted_type) {
+        switch (this.desktop_effects_map_type) {
             case "traditional":
             {
                 actor.orig_opacity = actor.opacity;
                 actor.set_pivot_point(0.5, 0.5);
+                actor.x -= 1;
                 actor.scale_x = 0.94;
                 actor.scale_y = 0.94;
                 actor.opacity = 0;
@@ -838,15 +878,11 @@ var WindowManager = class WindowManager {
 
                 let time = this.MAP_ANIMATION_TIME * this.window_effect_multiplier;
 
-                // Popups shouldn't be affected by the multiplier.
-                if (overridden_types.includes(actor._windowType)) {
-                    time = this.MENU_ANIMATION_TIME;
-                }
-
                 actor.ease({
                     opacity: actor.orig_opacity,
                     scale_x: 1,
                     scale_y: 1,
+                    x: actor.x + 1,
                     duration: time * EASING_MULTIPLIER,
                     mode: Clutter.AnimationMode.EASE_OUT_QUAD,
                     onStopped: () => this._mapWindowDone(cinnamonwm, actor),
@@ -913,8 +949,6 @@ var WindowManager = class WindowManager {
             actor.set_pivot_point(0, 0);
             actor.scale_y = 1;
             actor.scale_x = 1;
-            actor.translation_y = 0;
-            actor.translation_x = 0;
             cinnamonwm.completed_map(actor);
         }
     }
@@ -953,14 +987,7 @@ var WindowManager = class WindowManager {
 
         this._destroying.add(actor);
 
-        // menu effects are always traditional
-        let overridden_types = [Meta.WindowType.MENU,
-                                Meta.WindowType.DROPDOWN_MENU,
-                                Meta.WindowType.POPUP_MENU    ];
-
-        let adjusted_type = overridden_types.includes(actor._windowType) ? "traditional" : this.desktop_effects_close_type;
-
-        switch (adjusted_type) {
+        switch (this.desktop_effects_close_type) {
             case "fly":
             {
                 let [xSrc, ySrc] = actor.get_position();
@@ -1009,10 +1036,6 @@ var WindowManager = class WindowManager {
 
                         return;
                     }
-                    case Meta.WindowType.MENU:
-                    case Meta.WindowType.DROPDOWN_MENU:
-                    case Meta.WindowType.POPUP_MENU:
-                    // ??
                     default:
                     {
                         this._destroyWindowDone(cinnamonwm, actor);
@@ -1122,7 +1145,8 @@ var WindowManager = class WindowManager {
             // Muffin 5.2 window.showing_on_its_workspace() no longer
             // ends up filtering the desktop window (If I re-add it, it
             // breaks things elsewhere that rely on the new behavior).
-            if (meta_window.get_window_type() === Meta.WindowType.DESKTOP) {
+            if (meta_window.get_window_type() === Meta.WindowType.DESKTOP ||
+                meta_window.get_window_type() === Meta.WindowType.OVERRIDE_OTHER) {
                 continue;
             }
 
@@ -1171,6 +1195,11 @@ var WindowManager = class WindowManager {
             }
         }
 
+        if (to_windows.size === 0 && from_windows.size === 0) {
+            this._cinnamonwm.completed_switch_workspace();
+            return;
+        }
+
         kill_id = this._cinnamonwm.connect('kill-switch-workspace', cinnamonwm => {
             let iter = to_windows.forEach((actor) => {
                 cleanup_window_effect(actor);
@@ -1206,7 +1235,7 @@ var WindowManager = class WindowManager {
     showWorkspaceOSD() {
         this._hideWorkspaceOSD(true);
         if (global.settings.get_boolean('workspace-osd-visible')) {
-            let current_workspace_index = global.screen.get_active_workspace_index();
+            let current_workspace_index = global.workspace_manager.get_active_workspace_index();
             if (this.wm_settings.get_boolean('workspaces-only-on-primary')) {
                 this._showWorkspaceOSDOnMonitor(Main.layoutManager.primaryMonitor.index, current_workspace_index);
             }
@@ -1282,8 +1311,8 @@ var WindowManager = class WindowManager {
             return;
         }
         this._movingWindow = window;
-        let workspace = global.screen.get_active_workspace().get_neighbor(direction);
-        if (workspace != global.screen.get_active_workspace()) {
+        let workspace = global.workspace_manager.get_active_workspace().get_neighbor(direction);
+        if (workspace != global.workspace_manager.get_active_workspace()) {
             window.change_workspace(workspace);
             workspace.activate_with_focus(window, global.get_current_time());
         }
@@ -1298,7 +1327,7 @@ var WindowManager = class WindowManager {
     }
 
     moveToWorkspace(workspace, direction_hint) {
-        let active = global.screen.get_active_workspace();
+        let active = global.workspace_manager.get_active_workspace();
         // if (workspace != active) {
             // if (direction_hint)
                 // workspace.activate_with_direction_hint(direction_hint, global.get_current_time());
@@ -1318,7 +1347,7 @@ var WindowManager = class WindowManager {
             return;
         }
 
-        if (global.screen.n_workspaces === 1)
+        if (global.workspace_manager.n_workspaces === 1)
             return;
 
         if (bindingName === 'switch-to-workspace-left') {
@@ -1329,7 +1358,7 @@ var WindowManager = class WindowManager {
     }
 
     actionMoveWorkspaceLeft() {
-        let active = global.screen.get_active_workspace();
+        let active = global.workspace_manager.get_active_workspace();
         let neighbor = active.get_neighbor(Meta.MotionDirection.LEFT)
         if (active != neighbor) {
             this.moveToWorkspace(neighbor, Meta.MotionDirection.LEFT);
@@ -1337,7 +1366,7 @@ var WindowManager = class WindowManager {
     }
 
     actionMoveWorkspaceRight() {
-        let active = global.screen.get_active_workspace();
+        let active = global.workspace_manager.get_active_workspace();
         let neighbor = active.get_neighbor(Meta.MotionDirection.RIGHT)
         if (active != neighbor) {
             this.moveToWorkspace(neighbor, Meta.MotionDirection.RIGHT);
@@ -1345,15 +1374,15 @@ var WindowManager = class WindowManager {
     }
 
     actionMoveWorkspaceUp() {
-        global.screen.get_active_workspace().get_neighbor(Meta.MotionDirection.UP).activate(global.get_current_time());
+        global.workspace_manager.get_active_workspace().get_neighbor(Meta.MotionDirection.UP).activate(global.get_current_time());
     }
 
     actionMoveWorkspaceDown() {
-        global.screen.get_active_workspace().get_neighbor(Meta.MotionDirection.DOWN).activate(global.get_current_time());
+        global.workspace_manager.get_active_workspace().get_neighbor(Meta.MotionDirection.DOWN).activate(global.get_current_time());
     }
 
     actionFlipWorkspaceLeft() {
-        let active = global.screen.get_active_workspace();
+        let active = global.workspace_manager.get_active_workspace();
         let neighbor = active.get_neighbor(Meta.MotionDirection.LEFT);
         if (active != neighbor) {
             neighbor.activate(global.get_current_time());
@@ -1363,7 +1392,7 @@ var WindowManager = class WindowManager {
     }
 
     actionFlipWorkspaceRight() {
-        let active = global.screen.get_active_workspace();
+        let active = global.workspace_manager.get_active_workspace();
         let neighbor = active.get_neighbor(Meta.MotionDirection.RIGHT);
         if (active != neighbor) {
             neighbor.activate(global.get_current_time());
